hal/hald/linux2 acpi.c,1.45,1.46 pmu.c,1.19,1.20

Richard Hughes hughsient at freedesktop.org
Sun Jan 29 09:07:56 PST 2006


Update of /cvs/hal/hal/hald/linux2
In directory gabe:/tmp/cvs-serv13945/hald/linux2

Modified Files:
	acpi.c pmu.c 
Log Message:
2006-01-29  Richard Hughes <richard at hughsie.com>
* doc/spec/hal-spec.xml.in, hald/linux2/acpi.c (laptop_panel_refresh), hald/linux/pmu.c (laptop_panel_refresh), tools/hal-system-lcd-get-brightness, tools/hal-system-lcd-set-brightness:
Rename acpi_method to access_method and HAL_PROP_LAPTOP_PANEL_ACPI_METHOD->HAL_PROP_LAPTOP_PANEL_ACCESS_METHOD for the laptop_panel device.
This is required as the access method can now be "pmu" which is nothing to do with acpi. I'm not aware of this being used anywhere outside of HAL, so we should be okay changing the key name.


Index: pmu.c
===================================================================
RCS file: /cvs/hal/hal/hald/linux2/pmu.c,v
retrieving revision 1.19
retrieving revision 1.20
diff -u -d -r1.19 -r1.20
--- pmu.c	29 Jan 2006 15:51:39 -0000	1.19
+++ pmu.c	29 Jan 2006 17:07:54 -0000	1.20
@@ -213,8 +213,7 @@
 	hal_device_property_set_string (d, "info.category", "laptop_panel");
 	hal_device_property_set_string (d, "info.product", "Apple Laptop Panel");
 
-	/* this should really be laptop_panel.access_method */
-	hal_device_property_set_string (d, "laptop_panel.acpi_method", "pmu");
+	hal_device_property_set_string (d, "laptop_panel.access_method", "pmu");
 	/*
 	 * We can set laptop_panel.num_levels as it will not change, 
 	 * all powerbooks have 15 steps for brightness, where state 0




More information about the hal-commit mailing list
Index: acpi.c
===================================================================
RCS file: /cvs/hal/hal/hald/linux2/acpi.c,v
retrieving revision 1.45
retrieving revision 1.46
diff -u -d -r1.45 -r1.46
--- acpi.c	6 Jan 2006 18:47:11 -0000	1.45
+++ acpi.c	29 Jan 2006 17:07:54 -0000	1.46
@@ -702,10 +702,10 @@
 
 	hal_device_property_set_string (d, "info.product", desc);
 	/*
 	 * We will set laptop_panel.acpi_method as the scripts can use this to
 	 * determine the set/get parameters.
 	 */
-	hal_device_property_set_string (d, "laptop_panel.acpi_method", type);
+	hal_device_property_set_string (d, "laptop_panel.access_method", type);
 	/*
 	 * We can set laptop_panel.num_levels as it will not change, and allows us
 	 * to work out the percentage in the scripts.
@@ -702,10 +702,10 @@
 	hal_device_property_set_string (d, "info.product", desc);
 	/*
-	 * We will set laptop_panel.acpi_method as the scripts can use this to
+	 * We will set laptop_panel.access_method as the scripts can use this to
 	 * determine the set/get parameters.
 	 */
